Documentation
¶
Overview ¶
Package v1beta1 contains API Schema definitions for the sre v1beta1 API group +kubebuilder:object:generate=true +groupName=sre.amsy810.dev
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "sre.amsy810.dev", Version: "v1beta1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type CertCheck ¶
type CertCheck struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CertCheckSpec `json:"spec,omitempty"`
Status CertCheckStatus `json:"status,omitempty"`
}
CertCheck is the Schema for the certchecks API
func (*CertCheck) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertCheck.
func (*CertCheck) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CertCheck) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CertCheckList ¶
type CertCheckList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CertCheck `json:"items"`
}
CertCheckList contains a list of CertCheck
func (*CertCheckList) DeepCopy ¶
func (in *CertCheckList) DeepCopy() *CertCheckList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertCheckList.
func (*CertCheckList) DeepCopyInto ¶
func (in *CertCheckList) DeepCopyInto(out *CertCheckList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CertCheckList) DeepCopyObject ¶
func (in *CertCheckList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CertCheckSpec ¶
type CertCheckSpec struct {
Selector *metav1.LabelSelector `json:"selector,omitempty"`
Threshold int `json:"threshold,omitempty"`
}
CertCheckSpec defines the desired state of CertCheck
func (*CertCheckSpec) DeepCopy ¶
func (in *CertCheckSpec) DeepCopy() *CertCheckSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertCheckSpec.
func (*CertCheckSpec) DeepCopyInto ¶
func (in *CertCheckSpec) DeepCopyInto(out *CertCheckSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertCheckStatus ¶
type CertCheckStatus struct {
TargetCertsCount int `json:"targetCertsCount,omitempty"`
Certificates []Certificate `json:"certificates,omitempty"`
}
CertCheckStatus defines the observed state of CertCheck
func (*CertCheckStatus) DeepCopy ¶
func (in *CertCheckStatus) DeepCopy() *CertCheckStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertCheckStatus.
func (*CertCheckStatus) DeepCopyInto ¶
func (in *CertCheckStatus) DeepCopyInto(out *CertCheckStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Certificate ¶
type Certificate struct {
Name string `json:"name,omitempty"`
NotBefore metav1.Time `json:"notBefore,omitempty"`
NotAfter metav1.Time `json:"notAfter,omitempty"`
Active bool `json:"active,omitempty"`
}
func (*Certificate) DeepCopy ¶
func (in *Certificate) DeepCopy() *Certificate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Certificate.
func (*Certificate) DeepCopyInto ¶
func (in *Certificate) DeepCopyInto(out *Certificate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.